Skip to content
KitploitKITPLOIT
StrumentiBlog
Log in
Invia
StrumentiBlog
Invia

Strumenti di Hacking, PenTest e Cybersecurity per il tuo Arsenale di Sicurezza!

Kitploit è una directory di strumenti di hacking, cybersecurity e pentesting. Scopri gli ultimi aggiornamenti dei progetti per trovare vulnerabilità, analizzare sistemi, automatizzare i test e rafforzare la tua sicurezza.

··Feed·Contatto·Privacy·© 2026 Kitploit

Directory degli strumenti

Categorie

Vedi tutte le categorie
Loading categories
recon — Enumerare un target basato sui risultati di Nmap | Kitploit
Strumenti/GitHubGitHub/knowledge-wisdom-understanding/recon
Password CrackingRicognizioneScanner di VulnerabilitàMappatura della ReteScansione PorteEnumerazione DNS e SottodominiRaccolta InformazioniSicurezza WebFuzzing

Più Popolari

Vedi tutti →

Scopri gli strumenti più utilizzati dalla nostra community.

Esplora tutti gli strumenti

Sfoglia la nostra collezione di strumenti

Vedi tutti gli strumenti →
Condividi
CTF
Penetration Testing
Analisi DNS
GitHubknowledge-wisdom-understanding/recon

recon

Enumerare un target basato sui risultati di Nmap

Vedi Repository
7625152 anni faRevisionato da Kitploit

O.G. AUTO-RECON

Caratteristiche

  • Lo scopo di O.G. Auto-Recon è automatizzare la fase iniziale di raccolta informazioni e poi enumerare il più possibile in base a questi risultati.
  • Questo strumento è pensato per CTF e può essere piuttosto rumoroso. (Non è lo strumento più attento alla stealth...)
  • La sintassi dei comandi può essere facilmente modificata nelle impostazioni del Config. I nomi delle variabili $variable devono rimanere invariati.
  • Se viene rilevato Virtual Host Routing, O.G. Auto-Recon aggiungerà i nomi degli host al tuo file /etc/hosts e continuerà ad enumerare i nomi di host appena scoperti.
  • L'enumerazione DNS è limitata per ignorare i domini .com .co .eu .uk ecc... poiché questo strumento è stato progettato per CTF come, ad esempio, "hack the box". Proverà a trovare la maggior parte dei domini .htb se vengono rilevati server DNS.
  • Questo progetto utilizza vari strumenti autonomi e personalizzati per enumerare un target basandosi sui risultati di nmap.
  • Tutti i comandi e l'output vengono registrati in una cartella Report nella directory ~/.local/share/autorecon/report dell'utente, utilizzando il contesto di denominazione "report/IP-ADDRESS/" che sarà simile a report/10.10.10.108/ con una struttura ad albero di directory simile a questa struttura ad albero del report

INSTALLAZIONE

  • L'ambiente virtuale è il metodo preferito per l'installazione
mkdir -p ~/pyenv
python3 -m pip install virtualenv
virtualenv -p python3 ~/pyenv/autorecon
cd /opt
git clone https://github.com/Knowledge-Wisdom-Understanding/recon.git
cd recon
chmod +x setup.sh
./setup.sh
source ~/pyenv/autorecon/bin/activate
python3 -m pip install -r requirements.txt
python3 setup.py install

Utilizzo


       _____________          ____    ________________
      /___/___      \        /  / |  /___/__          \      Mr.P-Millz   _____
      O.G./  /   _   \______/__/  |______|__|_____ *   \_________________/__/  |___
       __/__/   /_\   \ |  |  \   __\/  _ \|  |       __/ __ \_/ ___\/  _ \|       |
      |   |     ___    \|  |  /|  | (  |_| )  |    |   \  ___/\  \__(  |_| )   |   |
      |___|____/\__\____|____/_|__|\_\____/|__|____|_  /\___  |\___  \____/|___|  /
      github.com/Knowledge-Wisdom-Understanding  \___\/  \__\/  \__\_/      \___\/ v4.2.0


usage:  autorecon -t 10.10.10.10

An Information Gathering and Enumeration Framework

optional arguments:
  -h, --help            show this help message and exit
  -t TARGET, --target TARGET
                        Single IPv4 Target to Scan
  -F, --FUZZ            auto fuzz found urls ending with .php for params
  -v, --version         Show Current Version
  -f FILE, --file FILE  File of IPv4 Targets to Scan
  -w [WEB], --web [WEB]
                        Get open ports for IPv4 address, then only Enumerate
                        Web & and Dns Services. -t,--target must be specified.
                        -w, --web takes a URL as an argument. i.e. python3
                        recon.py -t 10.10.10.10 -w secret
  -i {http,httpcms,ssl,sslcms,aquatone,smb,dns,ldap,removecolor,oracle,source,sort_urls,proxy,proxycms,fulltcp,topports,remaining,searchsploit,peaceout,ftpAnonDL,winrm} [{http,httpcms,ssl,sslcms,aquatone,smb,dns,ldap,removecolor,oracle,source,sort_urls,proxy,proxycms,fulltcp,topports,remaining,searchsploit,peaceout,ftpAnonDL,winrm} ...], --ignore {http,httpcms,ssl,sslcms,aquatone,smb,dns,ldap,removecolor,oracle,source,sort_urls,proxy,proxycms,fulltcp,topports,remaining,searchsploit,peaceout,ftpAnonDL,winrm} [{http,httpcms,ssl,sslcms,aquatone,smb,dns,ldap,removecolor,oracle,source,sort_urls,proxy,proxycms,fulltcp,topports,remaining,searchsploit,peaceout,ftpAnonDL,winrm} ...]
                        Service modules to ignore during scan.
  -s {http,httpcms,ssl,sslcms,aquatone,smb,dns,ldap,removecolor,oracle,source,sort_urls,proxy,proxycms,fulltcp,topports,remaining,searchsploit,peaceout,ftpAnonDL,winrm} [{http,httpcms,ssl,sslcms,aquatone,smb,dns,ldap,removecolor,oracle,source,sort_urls,proxy,proxycms,fulltcp,topports,remaining,searchsploit,peaceout,ftpAnonDL,winrm} ...], --service {http,httpcms,ssl,sslcms,aquatone,smb,dns,ldap,removecolor,oracle,source,sort_urls,proxy,proxycms,fulltcp,topports,remaining,searchsploit,peaceout,ftpAnonDL,winrm} [{http,httpcms,ssl,sslcms,aquatone,smb,dns,ldap,removecolor,oracle,source,sort_urls,proxy,proxycms,fulltcp,topports,remaining,searchsploit,peaceout,ftpAnonDL,winrm} ...]
                        Scan only specified service modules
  -b {ftp,smb,http,ssh}, --brute {ftp,smb,http,ssh}
                        Experimental! - Brute Force ssh,smb,ftp, or http. -t,
                        --target is REQUIRED. Must supply only one protocol at
                        a time. For ssh, first valid users will be enumerated
                        before password brute is initiated, when no user or
                        passwords are supplied as options.
  -p PORT, --port PORT  port for brute forcing argument. If no port specified,
                        default port will be used
  -u USER, --user USER  Single user name for brute forcing, for SSH, if no
                        user specified, will default to
                        wordlists/usernames.txt and bruteforce usernames
  -U USERS, --USERS USERS
                        List of usernames to try for brute forcing. Not yet
                        implimented
  -P PASSWORDS, --PASSWORDS PASSWORDS
                        List of passwords to try. Optional for SSH, By default
                        wordlists/probable-v2-top1575.txt will be used.

Per scansionare un singolo target ed enumerare basandosi sui risultati di nmap:

autorecon -t 10.10.10.10

Per enumerare il web con wordlist più grandi

  • Se non vuoi specificare una directory, puoi semplicemente inserire ' ' come argomento per --web
autorecon -t 10.10.10.10 -w secret
autorecon -t 10.10.10.10 -w somedirectory
autorecon -t 10.10.10.10 -w ' '

Tipicamente, al primo avvio, dovresti specificare solo l'opzione -t --target (autorecon -t 10.10.10.10) Prima di poter usare l'opzione -s --service per specificare moduli particolari, devi aver già eseguito il modulo topports. Ad esempio, se volessi saltare tutti gli altri moduli al primo avvio e scansionare solo il web dopo topports, potresti fare qualcosa come:

autorecon -t 10.10.10.10 -s topports dns http httpcms ssl sslcms sort_urls aquatone source

Oppure saltare completamente l'enumerazione web ma scansionare tutto il resto.

autorecon -t 10.10.10.10 -i dns http httpcms ssl sslcms sort_urls aquatone source

Il modulo dei servizi rimanenti dipende anch'esso dal modulo topports e/o fulltcp. Ora puoi saltare una scansione fulltcp se il target è lento. Tuttavia, tieni presente che La scansione UDP di nmap è inclusa nel modulo fulltcp, quindi saltare fulltcp comporterà la perdita di parte dell'enumerazione UDP.

Per scansionare + enumerare tutti gli indirizzi IPv4 nel file ips.txt

autorecon -f ips.txt

Per fuzzare tutti gli URL php trovati in cerca di parametri, puoi usare il flag -F --FUZZ senza argomento.

autorecon -t 10.10.10.10 --FUZZ

Brute force degli utenti SSH sulla porta predefinita 22. Se vengono trovati utenti validi univoci, brute force delle password

autorecon -t 10.10.10.10 -b ssh

Come sopra ma per SSH sulla porta 2222 ecc...

autorecon -t 10.10.10.10 -b ssh -p 2222
autorecon -t 10.10.10.10 -b ssh -p 2222 -u slickrick
Scarica lo strumento